"use babel";

/**
 * The goal of the geck-language module is to provide potential keywords
 * in a set that would often or at least likely be used for code completion
 * or as a grammar set.
 */
var Syntax = {
  keywords: [
    'Array',
    'Array_Var',
    'Begin',
    'ElseIf',
    'End',
    'EndIf',
    'Float',
    'Function',
    'Goto',
    'If',
    'Int',
    'Integer',
    'Label',
    'Long',
    'Map',
    'Player',
    'Ref',
    'Reference',
    'Scn',
    'ScriptName',
    'Set',
    'Short',
    'String_Var',
    'StringMap'
  ].join('|'),

  blocktypes: [
    'GameMode',
    'MenuMode',
    'OnActivate',
    'OnActorEquip',
    'OnActorUnequip',
    'OnAdd',
    'OnClose',
    'OnCombatEnd',
    'OnDeath',
    'OnDestructionStageChange',
    'OnDrop',
    'OnEquip',
    'OnGrab',
    'OnHit',
    'OnHitWith',
    'OnLoad',
    'OnMagicEffectHit',
    'OnMurder',
    'OnOpen',
    'OnPackageChange',
    'OnPackageDone',
    'OnPackageStart',
    'OnRelease',
    'OnReset',
    'OnSell',
    'OnStartCombat',
    'OnTrigger',
    'OnTriggerEnter',
    'OnTriggerLeave',
    'OnUnequip',
    'SayToDone',
    'ScriptEffectFinish',
    'ScriptEffectStart',
    'ScriptEffectUpdate'
  ].join('|'),

  geckFns: [
    'Abs',
    'Activate',
    'AddAchievement',
    'AddDecal',
    'AddFaceAnimNote|AFA',
    'AddFlames',
    'AddItemHealthPercent',
    'AddItem',
    'AddNote|A',
    'AddOcclusionPlane|AO',
    'AddPerk',
    'AddScriptPackage',
    'AddSPECIALPoints',
    'AddSpell',
    'AddTagSkills',
    'AddToFaction|Addfa',
    'AddTopic',
    'AdvancePCLevel|AdvLeve',
    'AdvancePCSkill|AdvSkil',
    'AgeRace',
    'ApplyImageSpaceModifier|imo',
    'AttachAshPile',
    'AutoDisplayObjectives',
    'Autosave',
    'BeginTrace|b',
    'BetaComment|B',
    'CalcLowPathToPoint|LP2',
    'CalcPathToPoint|P2',
    'CanHaveFlames',
    'CastImmediateOnSelf|cio',
    'Cast',
    'CenterOnCell|CO',
    'CenterOnExterior|CO',
    'CenterOnWorld|CO',
    'ClearActorsFactionsPlayerEnemyFlag',
    'ClearAdaptedLight|ca',
    'ClearDestruction',
    'ClearFactionPlayerEnemyFlag',
    'ClearLocationMarkers|cl',
    'ClearNoActivationSound',
    'ClearOwnership',
    'ClearScreenBlood|cs',
    'CloseAllMenus|ca',
    'CloseFile',
    'CompleteAllObjectives',
    'CompleteAllQuestStages|caq',
    'CompleteQuest',
    'CopySaves|CopySave',
    'Cos',
    'CreateDetectionEvent',
    'DamageActorValue|DamageA',
    'DamageObject|d',
    'DamageWeapon',
    'DeactivateAllHighlights|DA',
    'DebugCombatPlan|dc',
    'DebugMilesPS3|dm',
    'DeleteReference|za',
    'DisableAllActors|DisA',
    'DisableAllMines',
    'DisableLinkedPathPoints',
    'DisableNavMesh',
    'DisablePlayerControls',
    'Disable',
    'DispelAllSpells',
    'Dispel',
    'DrawSkeleton|da',
    'DropMe',
    'Drop',
    'DumpMasterFileSeekData',
    'DumpMenuPackingInfo|dpm',
    'DumpModelMap|DM',
    'DumpNiUpdates|dn',
    'DumpTexturePalette|DT',
    'DuplicateAllItems',
    'DuplicateNPCStats',
    'EnableFastTravel|EnableFas',
    'EnableLinkedPathPoints',
    'EnableNavMesh',
    'EnablePlayerControls',
    'Enable',
    'EnterTrigger',
    'EquipItem|EquipObjec',
    'EssentialDeathReload',
    'EvalActorTextures|EA',
    'EvaluatePackage|ev',
    'EvaluateSpellConditions|es',
    'Exists',
    'ExitGame|exi',
    'FadeSFX|FSF',
    'FireWeapon',
    'FlushNonPersistActors|Flus',
    'ForceActiveQuest',
    'ForceActorValue|ForceA',
    'ForceFileCache|ff',
    'ForceFlee|Fle',
    'ForceGroupStrategy|fg',
    'ForceRadioStationUpdate|FRS',
    'ForceRSXCrash|fRS',
    'ForceSave',
    'ForceTakeCover|TakeCove',
    'ForceTerminalBack',
    'ForceWeather|f',
    'FreezeRenderAccumulation|fr',
    'FriendDispositionBoost',
    'FunctionUnused16',
    'FunctionUnused19|unuse',
    'FunctionUnused20',
    'GetActionRef|getA',
    'GetActorAggroRadiusViolated',
    'GetActorCrimePlayerEnemy',
    'GetActorFactionPlayerEnemy',
    'GetActorsInHigh',
    'GetActorValueInfo|GetAVInf',
    'GetActorValue|GetA',
    'GetAlarmed',
    'GetAmountSoldStolen',
    'GetAngle',
    'GetAnimAction',
    'GetArmorRatingUpperBody',
    'GetArmorRating',
    'GetAttacked',
    'GetBarterGold',
    'GetBaseActorValue|GetBaseA',
    'GetBroadcastState',
    'GetButtonPressed',
    'GetCannibal',
    'GetCauseofDeath',
    'GetClassDefaultMatch',
    'GetClothingValue',
    'GetCombatTarget',
    'GetConcussed',
    'GetContainer',
    'GetCrimeKnown',
    'GetCrime',
    'GetCurrentAIPackage',
    'GetCurrentAIProcedure',
    'GetCurrentTime',
    'GetCurrentWeatherPercent|getweatherpc',
    'GetDayOfWeek',
    'GetDeadCount',
    'GetDead',
    'GetDefaultOpen',
    'GetDestroyed',
    'GetDestructionStage',
    'GetDetected',
    'GetDetectionLevel',
    'GetDialogueEmotionValue',
    'GetDialogueEmotion',
    'GetDisabled',
    'GetDisease',
    'GetDisposition',
    'GetDistance',
    'GetEquipped',
    'GetFactionCombatReaction',
    'GetFactionRankDifference',
    'GetFactionRank',
    'GetFactionReaction',
    'GetFactionRelation',
    'GetFatiguePercentage|GetFatigu',
    'GetForceRun',
    'GetForceSneak',
    'GetFriendHit',
    'GetFurnitureMarkerID',
    'GetGameSetting|GetG',
    'GetGlobalValue',
    'GetGold',
    'GetGroupMemberCount',
    'GetGroupTargetCount',
    'GetHasNote|Get',
    'GetHeadingAngle',
    'GetHealthPercentage',
    'GetHitLocation',
    'GetIdleDoneOnce',
    'GetIgnoreCrime',
    'GetIgnoreFriendlyHits|gif',
    'GetInCellParam',
    'GetInCell',
    'GetInFaction',
    'GetINISetting|GetIN',
    'GetInSameCell',
    'GetInWorldspace',
    'GetInZone',
    'GetIsAlerted',
    'GetIsAlignment',
    'GetIsClassDefault',
    'GetIsClass',
    'GetIsCreatureType',
    'GetIsCreature',
    'GetIsCurrentPackage',
    'GetIsCurrentWeather|getweathe',
    'GetIsFormType',
    'GetIsGhost',
    'GetIsID',
    'GetIsLockBroken',
    'GetIsObjectType',
    'GetIsPlayableRace',
    'GetIsRace',
    'GetIsReference',
    'GetIsSex',
    'GetIsUsedItemEquipType',
    'GetIsUsedItemType',
    'GetIsUsedItem',
    'GetIsVoiceType',
    'GetItemCount',
    'GetKillingBlowLimb',
    'GetKnockedState',
    'GetLastHitCritical',
    'GetLastPlayerAction',
    'GetLevel',
    'GetLineOfSight|GetLO',
    'GetLinkedRef',
    'GetLocked',
    'GetLockLevel',
    'GetMajorCrimeCount',
    'GetMapMarkerVisible',
    'GetMinorCrimeCount',
    'GetNoRumors',
    'GetObjectiveCompleted',
    'GetObjectiveDisplayed',
    'GetOffersServicesNow',
    'GetOpenState',
    'GetPackageTarget',
    'GetParentRef',
    'GetPCEnemyofFaction',
    'GetPCExpelled',
    'GetPCFactionAttack',
    'GetPCFactionMurder',
    'GetPCInFaction',
    'GetPCIsClass',
    'GetPCIsRace',
    'GetPCIsSex',
    'GetPCMiscStat|GetPCM',
    'GetPCSleepHours',
    'GetPermanentActorValue|GetPermA',
    'GetPersuasionNumber',
    'GetPlantedExplosive',
    'GetPlayerControlsDisabled',
    'GetPlayerGrabbedRef',
    'GetPlayerHasLastRiddenHorse',
    'GetPlayerName',
    'GetPlayerTeammateCount',
    'GetPlayerTeammate',
    'GetPos',
    'GetQuestCompleted|GetQ',
    'GetQuestRunning|GetQ',
    'GetQuestVariable',
    'GetRadiationLevel',
    'GetRandomPercent',
    'GetRestrained',
    'GetSandman',
    'GetScale',
    'GetScriptVariable',
    'GetSecondsPassed',
    'GetSelf|thi',
    'GetShouldAttack',
    'GetSitting',
    'GetSleeping',
    'GetSpellUsageNum',
    'GetStageDone',
    'GetStage',
    'GetStartingAngle',
    'GetStartingPos',
    'GetTalkedToPCParam',
    'GetTalkedToPC',
    'GetThreatRatio',
    'GetTimeDead',
    'GetTotalPersuasionNumber',
    'GetTrespassWarningLevel',
    'GetUnconscious',
    'GetUsedItemActivate',
    'GetUsedItemLevel',
    'GetVampire',
    'GetVATSBackAreaFree',
    'GetVATSBackTargetVisible',
    'GetVATSFrontAreaFree',
    'GetVATSFrontTargetVisible',
    'GetVATSLeftAreaFree',
    'GetVATSLeftTargetVisible',
    'GetVATSMode',
    'GetVATSRightAreaFree',
    'GetVATSRightTargetVisible',
    'GetVatsTargetHeight',
    'GetVATSValue',
    'GetWalkSpeed|GetWal',
    'GetWeaponAnimType',
    'GetWeaponHealthPerc',
    'GetWeaponHealth',
    'GetWindSpeed',
    'GetXPForNextLevel',
    'HairTint',
    'HasBeenEaten',
    'HasFlames',
    'HasFriendDisposition',
    'HasLoaded3D',
    'HasMagicEffect',
    'HasPerk',
    'Help',
    'HighlightAdditionalReference|HA',
    'HighlightBodyPart|HB',
    'IgnoreCrime',
    'IgnoreRenderPass|ir',
    'IsActionRef',
    'IsActorAVictim',
    'IsActorDetected',
    'IsActorEvil',
    'IsActorsAIOff',
    'IsActorTalkingThroughActivator',
    'IsActorUsingATorch',
    'IsActor',
    'IsAnimPlaying',
    'IsCellOwner',
    'IsChild',
    'IsCloudy',
    'IsCombatTarget',
    'IsContinuingPackagePCNear',
    'IsCurrentFurnitureObj',
    'IsCurrentFurnitureRef',
    'IsEssential',
    'IsFacingUp',
    'IsGoreDisabled',
    'IsGreetingPlayer',
    'IsGuard',
    'IsHorseStolen',
    'IsIdlePlaying',
    'IsImageSpaceActive',
    'IsInCombat',
    'IsInCriticalStage',
    'IsInDangerousWater',
    'IsInInterior',
    'IsInList',
    'IsInMyOwnedCell',
    'IsKillerObject',
    'IsKiller',
    'IsLastIdlePlayed',
    'IsLeftUp',
    'IsLimbGone',
    'IsMoving',
    'IsOwner',
    'IsPC1stPerson|pc1s',
    'IsPCAMurderer',
    'IsPCSleeping',
    'IsPlayerActionActive',
    'IsPlayerGrabbedRef',
    'IsPlayerMovingIntoNewSpace',
    'IsPlayersLastRiddenHorse',
    'IsPlayerTagSkill',
    'IsPleasant',
    'IsPS3',
    'IsRaining',
    'IsRidingHorse',
    'IsRunning',
    'IsShieldOut',
    'IsSneaking',
    'IsSnowing',
    'IsSpellTarget',
    'IsSwimming',
    'IsTalkingActivatorActor',
    'IsTalking',
    'IsTimePassing',
    'IsTorchOut',
    'IsTrespassing',
    'IsTurning',
    'IsWaiting',
    'IsWaterObject',
    'IsWeaponInList',
    'IsWeaponOut',
    'IsWeaponSkillType',
    'IsWin32',
    'IsXBox',
    'KillActor|kil',
    'KillAllActors|killal',
    'KillQuestUpdates|KQ',
    'LoadGame|loa',
    'Lock',
    'Log',
    'Long Name|Short Nam',
    'Look',
    'LoopGroup',
    'MarkForDelete',
    'MatchFaceGeometry',
    'MatchRace',
    'MenuMode',
    'ModActorValue|ModA',
    'ModAmountSoldStolen',
    'ModBarterGold',
    'ModDisposition',
    'ModFactionRank',
    'ModFactionReaction',
    'ModifyFaceGen|mf',
    'ModPCAttribute|ModPC',
    'ModPCMiscStat|ModPCM',
    'ModPCSkill|ModPC',
    'ModScale',
    'ModWaterShader|mw',
    'ModWeaponHealthPerc',
    'MovePipboyKnob|MP',
    'MoveToMarker|MoveT',
    'MoveToQuestTarget|movetoq',
    'OpenTeammateContainer',
    'OutputArchiveProfile|oa',
    'OutputLocalMapPictures|OLM',
    'OutputMemContexts|om',
    'OutputMemStats|omsf',
    'OutputMemStats|om',
    'OutputTextureUseMap|OTU',
    'PickIdle',
    'PickRefByID|PRI',
    'PipBoyRadioOff',
    'PipboyRadio|pra',
    'PlaceAtMeHealthPercent',
    'PlaceAtMe',
    'PlaceLeveledActorAtMe',
    'PlaceLocationMarker|pl',
    'PlayBink',
    'PlayerSpellBook|ps',
    'PlayExplosion',
    'PlayGroup',
    'PlayIdle',
    'PlayMagicEffectVisuals|PM',
    'PlayMagicShaderVisuals|PM',
    'PlayMusic',
    'PlaySound3D',
    'PlaySound',
    'PlayVATSCameras|pv',
    'PreloadMagicEffect',
    'PrintAiList|pa',
    'PrintHDRParam|PH',
    'PrintNPCDialog|pdialo',
    'PurgeCellBuffers|pc',
    'PushActorAway',
    'QuitGame|qq',
    'RefreshINI|REFIN',
    'RefreshShaders|R',
    'ReleaseWeatherOverride|rw',
    'ReloadCurrentClimate|rc',
    'ReloadCurrentWeather|rc',
    'RemoveAllItems',
    'RemoveFlames',
    'RemoveFromAllFactions',
    'RemoveFromFaction|Removefa',
    'RemoveImageSpaceModifier|rimo',
    'RemoveItem',
    'RemoveMerchantContainer',
    'RemoveMe',
    'RemoveNote|R',
    'RemovePerk',
    'RemoveScriptPackage',
    'RemoveSpell',
    'RenderTestCell|rt',
    'RenderTestHere|rt',
    'Reset3DState',
    'ResetAI',
    'ResetAllTerminals|ra',
    'ResetDialogueFlags|rd',
    'ResetFallDamageTimer',
    'ResetHealth',
    'ResetInterior',
    'ResetInventory',
    'ResetMemContexts|rm',
    'ResetPerformanceTimers|rp',
    'ResetPipboyManager',
    'ResetQuest',
    'RestoreActorValue|RestoreA',
    'ResurrectActor|resurrec',
    'RevertWorld|r',
    'RewardKarma',
    'RewardXP',
    'Rotate',
    'RunCellTest|rc',
    'RunMemoryPass|rm',
    'SameFactionAsPC',
    'SameFaction',
    'SameRaceAsPC',
    'SameRace',
    'SameSexAsPC',
    'SameSex',
    'SaveGame|sav',
    'SaveIniFiles|savein',
    'SaveWorld',
    'SayTo',
    'Say',
    'ScreenBloodTest|tsbTES',
    'SCRIPT COMMANDS',
    'ScriptEffectElapsedSeconds',
    'SelectPlayerSpell|spspel',
    'SendAssaultAlarm',
    'SendSherlockDebugText|ssd',
    'SendTrespassAlarm',
    'SetActorAlpha|SA',
    'SetActorFullName',
    'SetActorRefraction|sa',
    'SetActorsAI',
    'SetActorValue|SetA',
    'SetAlert',
    'SetAllReachable',
    'SetAllVisible',
    'SetAlly',
    'SetAngle',
    'SetAtStart',
    'SetAudioMultithreading|SA',
    'SetBarterGold',
    'SetBroadcastState',
    'SetCameraFOV|FO',
    'SetCellFullName',
    'SetCellImageSpace',
    'SetCellOwnership',
    'SetCellPublicFlag|setpubli',
    'SetClass',
    'SetClipDist',
    'SetCombatActionCost|sc',
    'SetCombatStyle|setc',
    'SetConsoleOuputFile|sco',
    'SetCriticalStage',
    'SetDebugText|sd',
    'SetDefaultOpen',
    'SetDepthOfFieldRange|sdof',
    'SetDestroyed',
    'SetDisposition|SetDis',
    'SetEmitterParticleMax',
    'SetEnemy',
    'SetEssential',
    'SetFactionRank',
    'SetFactionReaction',
    'SetFog',
    'SetForceRun',
    'SetForceSneak',
    'SetGameSetting|SetG',
    'SetGamma|s',
    'SetGhost',
    'SetGlobalRadialBlur|sgr',
    'SetGlobalTimeMultiplier|sgt',
    'SetHDRParam|SH',
    'SetHudGlowConstants|shg',
    'SetIgnoreFriendlyHits|sif',
    'SetImageSpaceGlow|SIS',
    'SetImageSpaceModifiersEnable|sism',
    'SetImageSpace',
    'SetInChargen',
    'SetINISetting|SetIN',
    'SetItemValue',
    'SetLastExtDoorActivated',
    'SetLevel',
    'SetLightingPasses|SL',
    'SetLocationSpecificLoadScreensOnly',
    'SetLODObjectDistance|SLO',
    'SetMaxAniso',
    'SetMerchantContainer',
    'SetMinimalUse',
    'SetMotionBlur|sm',
    'SetMPSParticleMax',
    'SetNoActivationSound',
    'SetNoAvoidance',
    'SetNoRumors',
    'SetNPCRadio|sn',
    'SetObjectiveCompleted',
    'SetObjectiveDisplayed',
    'SetOpenState',
    'SetOwnership',
    'SetPackDuration|SPDu',
    'SetPCCanUsePowerArmor',
    'SetPCEnemyofFaction',
    'SetPCExpelled',
    'SetPCFactionAttack',
    'SetPCFactionMurder',
    'SetPCSleepHours',
    'SetPCToddler',
    'SetPCYoung',
    'SetPlayerTagSkill',
    'SetPlayerTeammate',
    'SetPos',
    'SetQuestDelay',
    'SetQuestObject',
    'SetRestrained',
    'SetRigidBodyMass',
    'SetRumble',
    'SetScale',
    'SetSceneIsComplex',
    'SetShowQuestItems',
    'SetSize|CSiz',
    'SetSkyParam|SS',
    'SetSPECIALPoints',
    'SetStage',
    'SetTagSkills',
    'SetTalkingActivatorActor',
    'SetTargetDOF|stdo',
    'SetTargetFalloff|stf',
    'SetTargetRefractionFire|str',
    'SetTargetRefraction|st',
    'SetTaskThreadSleep',
    'SetTaskThreadUpdateSleep',
    'SetTerminalMenuPos|STM',
    'SetTreeMipmapBias|stm',
    'SetUFOCamSpeedMult|sucs',
    'SetUnconscious',
    'SetVATSTarget',
    'SetVel',
    'SetWeaponHealthPerc',
    'SetWeather|s',
    'SetZoneRespawns',
    'SexChange',
    'Show1stPerson|S1S',
    'ShowAllMapMarkers|tm',
    'ShowAnim|S',
    'ShowBarberMenu',
    'ShowBarterMenu|sb',
    'ShowChargenMenuModValues|scgmo',
    'ShowChargenMenuParams|scgm',
    'ShowChargenMenu|scg',
    'ShowClassMenu',
    'ShowComputersInterface|sc',
    'ShowDialogSubtitles',
    'ShowFullQuestLog|SFQ',
    'ShowHackingMiniGame|shm',
    'ShowHeadTrackTarget|SHead',
    'ShowInventory|in',
    'ShowLockpickMenuDebug|slpm',
    'ShowLockpickMenu|slp',
    'ShowMap',
    'ShowMessage',
    'ShowNameMenu',
    'ShowPivot|S',
    'ShowPlasticSurgeonMenu',
    'ShowQuestLog|SQ',
    'ShowQuestStages|SQ',
    'ShowQuests|S',
    'ShowQuestTargets|SQ',
    'ShowQuestVars|SQ',
    'ShowRaceMenu',
    'ShowRenderPasses|sr',
    'ShowRepairMenu|sr',
    'ShowScenegraph|SFS',
    'ShowScenegraph|SS',
    'ShowSPECIALBookMenuParams|ssbm',
    'ShowSPECIALBookMenu|ssb',
    'ShowSpellMaking',
    'ShowSubtitle',
    'ShowSurgeryMenu|ssm',
    'ShowTutorialMenu',
    'ShowVars|S',
    'ShowViewerStrings|sv',
    'ShowWarning',
    'ShowWhoDetectsPlayer|SWD',
    'Show|TS',
    'Sin',
    'SkipAnim',
    'SpeakSound',
    'Sqrt',
    'StartAllQuests|sa',
    'StartCannibal',
    'StartCombat',
    'StartConversation',
    'StartMasterFileSeekData',
    'StartMisterSandMan',
    'StartQuest',
    'StartRadioConversation',
    'StopCombatAlarmOnActor|SCAOnActo',
    'StopCombat',
    'StopLook',
    'StopMagicEffectVisuals|SM',
    'StopMagicShaderVisuals|SM',
    'StopQuest',
    'StopWaiting',
    'StreamMusic',
    'Tan',
    'TestAllCells|TA',
    'TestCode',
    'TestDegrade',
    'TestLocalMap|tl',
    'TestRaceSexTerimnal|trs',
    'TestSeenData|ts',
    'ToggleActorMover|ta',
    'ToggleActorsAI',
    'ToggleAiSchedules|TAI',
    'ToggleAI|TA',
    'ToggleBorders|T',
    'ToggleBoundVisGeom|tbv',
    'ToggleCastShadows|ts',
    'ToggleCellNode|TC',
    'ToggleCharControllerShape|TCC',
    'ToggleCollisionGeometry|TC',
    'ToggleCollision|TC',
    'ToggleCombatAI|tca',
    'ToggleCombatDebug|tc',
    'ToggleCombatStats|TC',
    'ToggleConversations|TCON',
    'ToggleDebugDecal|TD',
    'ToggleDebugText|TD',
    'ToggleDecalRendering|TD',
    'ToggleDepthBias|td',
    'ToggleDetectionStats|td',
    'ToggleDetection|TDETEC',
    'ToggleEmotions|tem',
    'ToggleEOFImageSpace|teofi',
    'ToggleFlyCam|tf',
    'ToggleFogOfWar|TFO',
    'ToggleFootIK|tfi',
    'ToggleFullHelp|TF',
    'ToggleFullScreenMotionBlur|tfsm',
    'ToggleGodMode|TG',
    'ToggleGrabIK|tgi',
    'ToggleGrassUpdate|TG',
    'ToggleGrass|T',
    'ToggleHDRDebug|TH',
    'ToggleHighProcess|THIGHPROCES',
    'ToggleLeaves|TL',
    'ToggleLiteBrite|tl',
    'ToggleLODLand|TL',
    'ToggleLookIK|tli',
    'ToggleLowProcess|TLOWPROCES',
    'ToggleMagicStats|TM',
    'ToggleMaterialGeometry|TM',
    'ToggleMenus|T',
    'ToggleMiddleHighProcess|TMHIGHPROCES',
    'ToggleMiddleLowProcess|TMLOWPROCES',
    'ToggleMotionBlur|tm',
    'ToggleMultiboundCheck|mb',
    'ToggleNavMesh|TN',
    'ToggleOcclusion|toc',
    'TogglePathingInfoFunction|TP',
    'TogglePathLine|TP',
    'TogglePrimitives|TP',
    'ToggleRagdollAnim|tr',
    'ToggleRefractionDebug|tr',
    'ToggleSafeZone|TS',
    'ToggleScripts|TSC',
    'ToggleShadowVolumes|TS',
    'ToggleSky|T',
    'ToggleSPURenderBatch|tSPUR',
    'ToggleSPUTransformUpdate|tSPUT',
    'ToggleTestLight|TT',
    'ToggleTrees|T',
    'ToggleVATSLight|TV',
    'ToggleWaterRadius|TW',
    'ToggleWaterSystem|TW',
    'ToggleWireframe|TW',
    'TrapUpdate',
    'TriggerHitShader|th',
    'TriggerHUDShudder|huds',
    'TriggerLODApocalypse',
    'TriggerScreenBlood|ts',
    'UnequipItem|UnEquipObjec',
    'UnLock',
    'UnusedFunction0',
    'UnusedFunction10',
    'UnusedFunction11',
    'UnusedFunction12',
    'UnusedFunction13',
    'UnusedFunction14',
    'UnusedFunction15',
    'UnusedFunction17',
    'UnusedFunction18',
    'UnusedFunction1',
    'UnusedFunction21',
    'UnusedFunction22',
    'UnusedFunction26',
    'UnusedFunction27',
    'UnusedFunction28',
    'UnusedFunction29',
    'UnusedFunction9',
    'UnusedFunction',
    'UseWeapon',
    'Verbose|VERBOS',
    'Wait',
    'WakeUpPC',
    'WasteMemory|w',
    'WaterDeepColor|dee',
    'WaterReflectionColor|ref',
    'WaterShallowColor|shallo',
    'WhichServiceMenu'
  ].join('|'),

  vegasFns: [
    'AddReputation',
    'AddReputationExact',
    'GetReputation',
    'GetReputationPct',
    'GetReputationThreshold',
    'IsActorsAIOff',
    'IsHardcore',
    'IsPlayerInRegion',
    'MoveToMarkerWithFade',
    'RemoveAllTypedItems',
    'RemoveRecurringFromChallenge',
    'RemoveReputation',
    'RemoveReputationExact',
    'ShowCaravanMenu',
    'ShowLoveTesterMenuParams',
    'SortUIListBox',
    'UnlockChallenge'
  ].join('|'),

  foseFns: [
    'AddSpellNS',
    'Ceil',
    'CompareNames',
    'Con_CloseAllMenus',
    'Con_GetINISetting',
    'Con_LoadGame',
    'Con_QuitGame',
    'Con_RefreshINI',
    'Con_SaveINI',
    'Con_Save',
    'Con_SetCameraFOV',
    'Con_SetGameSetting',
    'Con_SetINISetting',
    'Con_SetVel',
    'DebugPrint|DBPrintC',
    'DisableControl',
    'DisableKey',
    'EnableControl',
    'EnableKey',
    'Exp',
    'Floor',
    'Fmod',
    'GetAltControl',
    'GetArmorArmorRating',
    'GetAttackDamage',
    'GetBaseHealth',
    'GetBaseObject',
    'GetControl',
    'GetCrosshairRef',
    'GetCurrentHealth',
    'GetCurrentObjective',
    'GetCurrentQuest',
    'GetDebugMode',
    'GetEquippedCurrentHealth',
    'GetEquippedObject',
    'GetEquipType',
    'GetEyes',
    'GetFirstRefInCell',
    'GetFirstRef',
    'GetFOSEBeta',
    'GetFOSERevision',
    'GetFOSEVersion',
    'GetGameLoaded',
    'GetGameRestarted',
    'GetHairLength',
    'GetHair',
    'GetHotkeyItem',
    'GetInventoryObject',
    'GetItemValue',
    'GetKeyPress',
    'GetLinkedDoor',
    'GetModIndex',
    'GetMouseButtonPress',
    'GetNextRef',
    'GetNthQuestObjective',
    'GetNumericGameSetting',
    'GetNumericINISetting',
    'GetNumItems',
    'GetNumKeysPressed',
    'GetNumLoadedMods',
    'GetNumMouseButtonsPressed',
    'GetNumRefsInCell',
    'GetNumRefs',
    'GetObjectEffect',
    'GetObjectType',
    'GetOpenKey',
    'GetOwner',
    'GetOwningFactionRequiredRank',
    'GetParentCellOwner',
    'GetParentCellOwningFactionRequiredRank',
    'GetParentCell',
    'GetParentWorldspace',
    'GetQuestObjectiveCount',
    'GetRefCount',
    'GetRepairList',
    'GetScript',
    'GetSourceModIndex',
    'GetTeleportCell',
    'GetUIFloat',
    'GetWeaponActionPoints',
    'GetWeaponAimArc',
    'GetWeaponAmmoUse',
    'GetWeaponAmmo',
    'GetWeaponAnimAttackMult',
    'GetWeaponAnimJamTime',
    'GetWeaponAnimMult',
    'GetWeaponAnimReloadTime',
    'GetWeaponAnimShotsPerSec',
    'GetWeaponAttackAnimation',
    'GetWeaponBaseVATSChance',
    'GetWeaponClipRounds',
    'GetWeaponCritChance',
    'GetWeaponCritDamage',
    'GetWeaponCritEffect',
    'GetWeaponFireDelayMax',
    'GetWeaponFireDelayMin',
    'GetWeaponFireRate',
    'GetWeaponHandGrip',
    'GetWeaponHasScope',
    'GetWeaponIsAutomatic',
    'GetWeaponLimbDamageMult',
    'GetWeaponMaxRange',
    'GetWeaponMinRange',
    'GetWeaponMinSpread',
    'GetWeaponNumProjectiles',
    'GetWeaponProjectile',
    'GetWeaponReach',
    'GetWeaponReloadAnim',
    'GetWeaponResistType',
    'GetWeaponRumbleDuration',
    'GetWeaponRumbleLeftMotor',
    'GetWeaponRumbleRightMotor',
    'GetWeaponRumbleWaveLength',
    'GetWeaponSightFOV',
    'GetWeaponSightUsage',
    'GetWeaponSkill',
    'GetWeaponSpread',
    'GetWeaponType',
    'GetWeight',
    'GoTo',
    'Goto',
    'HoldKey',
    'IsClonedForm',
    'IsControlDisabled',
    'IsControlPressed',
    'IsControl',
    'IsFormValid',
    'IsKeyDisabled',
    'IsKeyPressed',
    'IsModLoaded',
    'IsPowerArmor',
    'IsReference',
    'IsScripted',
    'Label',
    'LeftShift',
    'ListAddForm',
    'ListAddReference',
    'ListGetCount',
    'ListGetFormIndex',
    'ListGetNthForm',
    'ListRemoveForm',
    'ListRemoveNthForm',
    'ListReplaceForm',
    'ListReplaceNthForm',
    'Log10',
    'LogicalAnd',
    'LogicalNot',
    'LogicalOr',
    'LogicalXor',
    'MenuHoldKey',
    'MenuReleaseKey',
    'MenuTapKey',
    'Pow',
    'PrintActiveTile',
    'PrintToConsole|PrintC',
    'ReleaseKey',
    'RemoveScript',
    'RightShift',
    'SetAltControl',
    'SetAttackDamage',
    'SetBaseItemValue',
    'SetControl',
    'SetDebugMode',
    'SetEquippedCurrentHealth',
    'SetIsControl',
    'SetIsPowerArmor',
    'SetName',
    'SetNumericGameSetting',
    'SetNumericINISetting',
    'SetObjectHealth',
    'SetOpenKey',
    'SetRepairList',
    'SetScript',
    'SetUIFloat',
    'SetUIString',
    'SetWeaponActionPoints',
    'SetWeaponAimArc',
    'SetWeaponAmmoUse',
    'SetWeaponAmmo',
    'SetWeaponAnimAttackMult',
    'SetWeaponAnimMult',
    'SetWeaponAttackAnimation',
    'SetWeaponBaseVATSChance',
    'SetWeaponClipRounds',
    'SetWeaponCritChance',
    'SetWeaponCritDamage',
    'SetWeaponCritEffect',
    'SetWeaponHandGrip',
    'SetWeaponIsAutomatic',
    'SetWeaponLimbDamageMult',
    'SetWeaponMaxRange',
    'SetWeaponMinRange',
    'SetWeaponMinSpread',
    'SetWeaponNumProjectiles',
    'SetWeaponProjectile',
    'SetWeaponReach',
    'SetWeaponReloadAnim',
    'SetWeaponSightFOV',
    'SetWeaponSightUsage',
    'SetWeaponSpread',
    'SetWeaponType',
    'SetWeight',
    'TapControl',
    'TapKey',
    'TempCloneForm'
  ].join('|'),

  nvseFns: [
    'ActorValueToString',
    'ActorValueToStringC',
    'AddItemHealthPercentOwner',
    'AddItemOwnership',
    'AddPackageAt',
    'Ar_Append',
    'Ar_BadNumericIndex',
    'Ar_BadStringIndex',
    'Ar_Construct',
    'Ar_Copy',
    'Ar_CustomSort',
    'Ar_DeepCopy',
    'Ar_Dump',
    'Ar_DumpID',
    'Ar_Erase',
    'Ar_Find',
    'Ar_First',
    'Ar_HasKey',
    'Ar_Insert',
    'Ar_InsertRange',
    'Ar_Keys',
    'Ar_Last',
    'Ar_List',
    'Ar_Map',
    'Ar_Next',
    'Ar_Null',
    'Ar_Prev',
    'Ar_Range',
    'Ar_Resize',
    'Ar_Size',
    'Ar_Sort',
    'Ar_SortAlpha',
    'AsciiToChar',
    'Break',
    'BuildRef',
    'Call',
    'CharToAscii',
    'ClearBit',
    'ClearHotkey',
    'ClearOpenKey',
    'CompareScripts',
    'Con_Inv',
    'Con_SCOF',
    'Con_SetUFOCamSpeedMult',
    'Con_ShowVars',
    'Con_SQV',
    'Con_TCL',
    'Con_TDT',
    'Con_TFC',
    'Con_ToggleMenus',
    'Continue',
    'CopyIR',
    'CreateTempRef',
    'EndVATScam',
    'EquipItem2',
    'EquipMe',
    'Eval',
    'Foreach',
    'GenericAddForm',
    'GenericDeleteForm',
    'GenericGetForm',
    'GenericReplaceForm',
    'GetActiveFactions',
    'GetActiveRanks',
    'GetActorBaseFlagsHigh',
    'GetActorBaseFlagsLow',
    'GetAgeClass',
    'GetAllModLocalData',
    'GetAltPerkRank',
    'GetAmmoCasing',
    'GetAmmoConsumedPercent',
    'GetAmmoSpeed',
    'GetArmorDT',
    'GetArrayVariable',
    'GetBaseFactions',
    'GetBaseForm',
    'GetBaseNthFaction',
    'GetBaseNthRank',
    'GetBaseNumFactions',
    'GetBasePackages',
    'GetBaseRanks',
    'GetBaseSpellListLevSpells',
    'GetBaseSpellListSpells',
    'GetBipedIconPath',
    'GetBipedModelPath',
    'GetCallingScript',
    'GetConsoleEcho',
    'GetCurrentPackage',
    'GetCurrentScript',
    'GetDebugSelection',
    'GetDefaultForms',
    'GetDialogueSpeaker',
    'GetDialogueSubject',
    'GetDialogueTarget',
    'GetEquipmentBipedMask',
    'GetEquipmentSlotsMask',
    'GetEquippedWeaponModFlags',
    'GetFactionRankFemaleNames',
    'GetFactionRankNames',
    'GetFalloutDirectory',
    'GetFirstRefForItem',
    'GetFormIDString',
    'GetGridsToLoad',
    'GetHairColor',
    'GetHeadParts',
    'GetIconPath',
    'GetInGrid',
    'GetInGridInCell',
    'GetInvRefsForItem',
    'GetKeyName',
    'GetLevCharacterRefs',
    'GetLevCreatureRefs',
    'GetListForms',
    'GetLocalRefIndex',
    'GetModelPath',
    'GetModLocalData',
    'GetName',
    'GetNextRefForItem',
    'GetNPCHeight',
    'GetNPCWeight',
    'GetNthDefaultForm',
    'GetNthExplicitRef',
    'GetNthFactionRankName',
    'GetNthModName',
    'GetNthPackage',
    'GetNumericIniSetting',
    'GetNumExplicitRefs',
    'GetNumRanks',
    'GetNVSEBeta',
    'GetNVSERevision',
    'GetNVSEVersion',
    'GetPackageCount',
    'GetPackageLocation',
    'GetPackageLocationRadius',
    'GetPackageTargetDistance',
    'GetPaired',
    'GetPerkRank',
    'GetPermanent',
    'GetPlayerCurrentAmmo',
    'GetPlayerCurrentAmmoRounds',
    'GetPluginVersion',
    'GetRace',
    'GetRaceEyes',
    'GetRaceHairs',
    'GetRaceName',
    'GetRawFormIDString',
    'GetRefs',
    'GetRefsInCell',
    'GetRefVariable',
    'GetRespawn',
    'GetScopeModelPath',
    'GetStringGameSetting',
    'GetStringIniSetting',
    'GetTexturePath',
    'GetTFC',
    'GetTokenRef',
    'GetTokenValue',
    'GetUserTime',
    'GetVariable',
    'GetWeaponFlags1',
    'GetWeaponFlags2',
    'GetWeaponItemMod',
    'GetWeaponItemModValue1',
    'GetWeaponItemModValue2',
    'GetWeaponLongBursts',
    'GetWeaponRequiredSkill',
    'GetWeaponRequiredStrength',
    'GetWeaponRumbleWavelength',
    'HasOwnership',
    'HasVariable',
    'IsDigit',
    'IsEquipped',
    'IsLetter',
    'IsOwned',
    'IsPersistent',
    'IsPlayable',
    'IsPlayerSwimming',
    'IsPluginInstalled',
    'IsPrintable',
    'IsPunctuation',
    'IsQuestItem',
    'IsRefInList',
    'IsUpperCase',
    'Let',
    'ListClear',
    'Loop',
    'MessageBoxEx',
    'MessageEx',
    'ModLocalDataExists',
    'NumToHex',
    'PickOneOf',
    'Print',
    'PrintDebug|PrintD',
    'QFromAxisAngle',
    'QFromEuler',
    'QInterpolate',
    'QMultQuatQuat',
    'QMultQuatVector3',
    'QNormalize',
    'QToEuler',
    'Rand',
    'RemoveAllPackages',
    'RemoveMeIR',
    'RemoveModLocalData',
    'RemovePackageAt',
    'ResetAllVariables',
    'RunScript',
    'SetActorBaseFlagsHigh',
    'SetActorBaseFlagsLow',
    'SetArmorArmorRating',
    'SetArmorDT',
    'SetBipedIconPathEX',
    'SetBipedModelPathEx',
    'SetBipedModelPathEX',
    'SetBit',
    'SetConsoleEcho',
    'SetCurrentHealth',
    'SetEquipmentBipedMask',
    'SetEquipmentSlotsMask',
    'SetEquippedWeaponModFlags',
    'SetEyes',
    'SetFunctionValue',
    'SetHair',
    'SetHairColor',
    'SetHairLength',
    'SetHotkeyItem',
    'SetIconPath',
    'SetIconPathEX',
    'SetIsPlayable',
    'SetModelPath',
    'SetModelPathEX',
    'SetModLocalData',
    'SetNameEx',
    'SetNPCHeight',
    'SetNPCWeight',
    'SetNthDefaultForm',
    'SetNthFactionRankNameEX',
    'SetNthPackage',
    'SetNumericIniSetting',
    'SetOwningFactionRequiredRank',
    'SetPackageLocationRadius',
    'SetPackageLocationReference',
    'SetPackageTargetDistance',
    'SetPackageTargetReference',
    'SetPermanent',
    'SetPlayerCurrentAmmoRounds',
    'SetQuestItem',
    'SetRefCount',
    'SetRefVariable',
    'SetRespawn',
    'SetScopeModelPath',
    'SetStringGameSettingEX',
    'SetStringIniSetting',
    'SetTexturePath',
    'SetTokenRef',
    'SetTokenValue',
    'SetTokenValueAndRef',
    'SetUIStringEx',
    'SetVariable',
    'SetWeaponFireRate',
    'SetWeaponFlags1',
    'SetWeaponFlags2',
    'SetWeaponLongBursts',
    'SetWeaponRequiredSkill',
    'SetWeaponRequiredStrength',
    'SetWeaponResistType',
    'SetWeaponSkill',
    'Sv_Compare',
    'Sv_Construct',
    'Sv_Count',
    'Sv_Destruct',
    'Sv_Erase',
    'Sv_Find',
    'Sv_GetChar',
    'Sv_Insert',
    'Sv_Length',
    'Sv_Percentify',
    'Sv_Replace',
    'Sv_Set',
    'Sv_Split',
    'Sv_SubString',
    'Sv_ToLower',
    'Sv_ToNumeric',
    'Sv_ToUpper',
    'TestExpr',
    'ToLower',
    'ToNumber',
    'ToString',
    'ToUpper',
    'TypeOf',
    'UnequipMe',
    'Update3D',
    'V3Crossproduct',
    'V3Length',
    'V3Normalize',
    'While'
  ].join('|'),

  nxFns: [
    'NX_ClrEVFl',
    'NX_ClrEVFo',
    'NX_ClrEVSt',
    'NX_GetEVFl',
    'NX_GetEVFlAr',
    'NX_GetEVFo',
    'NX_GetEVFoAr',
    'NX_GetEVSt',
    'NX_GetEVStAr',
    'NX_GetQVEVFL',
    'NX_GetRandom',
    'NX_IsInList',
    'NX_IsUsingSkeleton',
    'NX_SetEVFl',
    'NX_SetEVFo',
    'NX_SetEVSt'
  ].join('|'),
  
  lutanaFns: [
    'AchievementFix',
    'AddNoteNS',
    'AddRecipeInputForm',
    'AddRecipeOutputForm',
    'BaseAddItem',
    'BaseAddItemHealth',
    'BaseGetItemCount',
    'BaseRemoveItem',
    'ClearAllHotkeys',
    'Console',
    'CrosshairRefInList',
    'DisableButton',
    'DisableTrigger',
    'DumpLevList',
    'EnableButton',
    'EnableTrigger',
    'Fcos',
    'Fsin',
    'Fsqrt',
    'GetActiveQuest',
    'GetCellCoords',
    'GetCellRefs',
    'GetCellWaterForm',
    'GetCellWaterHeight',
    'GetChallengeInterval',
    'GetChallengeThreshold',
    'GetChallengeType',
    'GetChallengeValue1',
    'GetChallengeValue2',
    'GetChallengeValue3',
    'GetChanceNone',
    'GetChanceNoneGlobal',
    'GetController',
    'GetDeadZoneX',
    'GetDeadZoneY',
    'GetDefaultMessageTime',
    'GetDistance2D',
    'GetDistance3D',
    'GetFilesInFolder',
    'GetFoldersInFolder',
    'GetFormCountType',
    'GetFormFlag',
    'GetFormFromMod',
    'GetFormMods',
    'GetFormRecipeOutputs',
    'GetFormRecipes',
    'GetFormRefs',
    'GetGlobalTimeMultiplier',
    'GetImpactDataSet',
    'GetIngestibleFlag',
    'GetINIFloat',
    'GetINISection',
    'GetINISectionNames',
    'GetINIString',
    'GetInventoryWeight',
    'GetLeftStickX',
    'GetLeftStickY',
    'GetLeftTrigger',
    'GetLeveledListFlags',
    'GetLevItemIndexByForm',
    'GetLevItemIndexByLevel',
    'GetLightFade',
    'GetLightFalloff',
    'GetLightRGB',
    'GetLNVersion',
    'GetLoadedType',
    'GetLoadedTypeArray',
    'GetLoadScreenTexture',
    'GetLoadScreenType',
    'GetLoadScreenTypeTextRGB',
    'GetLockedOut',
    'GetMapMarkerHidden',
    'GetMapMarkerName',
    'GetMapMarkerRep',
    'GetMapMarkerTravel',
    'GetMapMarkerType',
    'GetMessageDisplayTime',
    'GetModName',
    'GetNthLevItem',
    'GetNthLevItemCount',
    'GetNthLevItemLevel',
    'GetNthPerkEntryForm',
    'GetNthPerkEntryFunction',
    'GetNthPerkEntryString',
    'GetNthPerkEntryType',
    'GetNthPerkEntryValue1',
    'GetNthPerkEntryValue2',
    'GetNumLevItems',
    'GetPasswordNote',
    'GetPCCanUsePowerArmor',
    'GetPerkEntryCount',
    'GetPerkLevel',
    'GetPickupSound',
    'GetPlayerRegions',
    'GetPressedButtons',
    'GetPutdownSound',
    'GetRadioBroadcastType',
    'GetRadioPosRef',
    'GetRadioRadius',
    'GetRadioStatic',
    'GetRadius',
    'GetRecipeCategory',
    'GetRecipeInputCount',
    'GetRecipeInputForms',
    'GetRecipeOutputCount',
    'GetRecipeOutputForms',
    'GetRecipeRequiredSkill',
    'GetRecipeRequiredSkillLevel',
    'GetRecipeSubcategory',
    'GetReferenceFlag',
    'GetRightStickX',
    'GetRightStickY',
    'GetRightTrigger',
    'GetSavedForms',
    'GetSelfModIndex',
    'GetShowQuestItems',
    'GetStringSetting',
    'GetTerminalLock',
    'GetTimeStamp',
    'GetWaterFormEffect',
    'GetWaterTrait',
    'GetWeaponCritFlags',
    'GetWeaponImpulseDistance',
    'GetWeaponKillImpulse',
    'GetWeaponVATSEffect',
    'GetWorldspaceParentWorldspace',
    'GetZone',
    'HasPerkRank',
    'HoldButton',
    'HoldTrigger',
    'IsButtonDisabled',
    'IsButtonHeld',
    'IsButtonPressed',
    'IsFormOverridden',
    'IsMapMarker',
    'IsParentActivateOnly',
    'IsRadioRef',
    'IsSkillMagazine',
    'IsTrait',
    'IsTriggerDisabled',
    'IsTriggerHeld',
    'LeveledListAddForm',
    'LeveledListClear',
    'LeveledListRemoveForm',
    'LeveledListReplaceForm',
    'LNGetName',
    'LNIsPlayable',
    'LNSetIsPlayable',
    'LNSetName',
    'MD5File',
    'OnButtonDown',
    'OnButtonUp',
    'OnCellEnter',
    'OnCellExit',
    'OnControlDown',
    'OnControlUp',
    'OnCrosshairOff',
    'OnCrosshairOn',
    'OnKeyDown',
    'OnKeyUp',
    'OnPlayerGrab',
    'OnPlayerRelease',
    'PlayerHasKey',
    'ReleaseButton',
    'ReleaseTrigger',
    'RemoveINIKey',
    'RemoveINISection',
    'RemoveNthLevItem',
    'RemoveRecipeInputForm',
    'RemoveRecipeOutputForm',
    'ReplaceRecipeInputForm',
    'ReplaceRecipeOutputForm',
    'RestoreHotkeys',
    'SaveForm',
    'SaveHotkeys',
    'Search',
    'SetBaseForm',
    'SetCellWaterHeight',
    'SetChallengeInterval',
    'SetChallengeThreshold',
    'SetChallengeValue1',
    'SetChallengeValue2',
    'SetChallengeValue3',
    'SetChanceNone',
    'SetDeadZoneX',
    'SetDeadZoneY',
    'SetDefaultMessageTime',
    'SetFormFlag',
    'SetGlobalValue',
    'SetHotkey',
    'SetImpactDataSet',
    'SetIngestibleFlag',
    'SetINIFloat',
    'SetINISection',
    'SetINIString',
    'SetLeveledListFlags',
    'SetLightFade',
    'SetLightFalloff',
    'SetLightRGB',
    'SetLinkedRef',
    'SetLoadScreenTexture',
    'SetLoadScreenType',
    'SetLoadScreenTypeTextRGB',
    'SetLockedOut',
    'SetMapMarkerHidden',
    'SetMapMarkerName',
    'SetMapMarkerRep',
    'SetMapMarkerTravel',
    'SetMapMarkerType',
    'SetMapMarkerVisible',
    'SetNthPerkEntryForm',
    'SetNthPerkEntryFunction',
    'SetNthPerkEntryString',
    'SetNthPerkEntryValue1',
    'SetNthPerkEntryValue2',
    'SetOnTriggerDownEventHandler',
    'SetOnTriggerUpEventHandler',
    'SetPasswordNote',
    'SetPerkRank',
    'SetPickupSound',
    'SetPutdownSound',
    'SetRadioBroadcastType',
    'SetRadioPosRef',
    'SetRadioRadius',
    'SetRadioStatic',
    'SetRadius',
    'SetRecipeCategory',
    'SetRecipeInputCount',
    'SetRecipeOutputCount',
    'SetRecipeRequiredSkill',
    'SetRecipeRequiredSkillLevel',
    'SetRecipeSubcategory',
    'SetReferenceFlag',
    'SetStringSetting',
    'SetVariableFloat',
    'SetVariableRef',
    'SetWaterTrait',
    'SetWeaponCritFlags',
    'SetWeaponImpulseDistance',
    'SetWeaponKillImpulse',
    'SetWeaponVATSEffect',
    'SHA1File',
    'SortFormsByType',
    'TapButton',
    'TapTrigger'
  ].join('|'),
  
  jipFns: [
    'ActorHasEffect',
    'AddAmmoEffect',
    'AddBaseEffectListEffect',
    'AddDestructionStage',
    'AddItemAlt',
    'AddNewEffect',
    'AddObjectiveTarget',
    'AddPrimitive',
    'AddRefMapMarker',
    'AddScriptVariable',
    'Ar_Cat',
    'AttachAshPileEx',
    'AuxiliaryVariableErase',
    'AuxiliaryVariableEraseAll',
    'AuxiliaryVariableGetAll',
    'AuxiliaryVariableGetAsArray',
    'AuxiliaryVariableGetFloat',
    'AuxiliaryVariableGetRef',
    'AuxiliaryVariableGetSize',
    'AuxiliaryVariableGetString',
    'AuxiliaryVariableGetType',
    'AuxiliaryVariableSetFloat',
    'AuxiliaryVariableSetFromArray',
    'AuxiliaryVariableSetRef',
    'AuxiliaryVariableSetString',
    'CastImmediate',
    'ClearActiveQuest',
    'ClearJIPSavedData',
    'ClearMessageQueue',
    'ClearModNVSEVars',
    'ClickMenuButton',
    'ClimateAddWeatherType',
    'ClimateRemoveWeatherType',
    'CopyFaceGenFrom',
    'CreatureHasModel',
    'CrippleLimb',
    'DisableNavMeshAlt',
    'DismemberLimb',
    'DropAlt',
    'DropMeAlt',
    'EnableNavMeshAlt',
    'EquipItemAlt',
    'EquipItemData',
    'FaceObject',
    'FakeScriptEvent',
    'FileExists',
    'ForceActorDetectionValue',
    'FreePlayer',
    'GetActivatorPrompt',
    'GetActivatorRadioStation',
    'GetActivatorSoundActivate',
    'GetActivatorSoundLooping',
    'GetActivatorWaterType',
    'GetActiveEffects',
    'GetActiveMenuMode',
    'GetActiveUIComponentFullName',
    'GetActiveUIComponentID',
    'GetActiveUIComponentName',
    'GetActorAlpha',
    'GetActorDiveBreath',
    'GetActorLeveledList',
    'GetActorLevelingData',
    'GetActorLightAmount',
    'GetActorProcessingLevel',
    'GetActorsByProcessingLevel',
    'GetActorTemplate',
    'GetActorTemplateFlag',
    'GetActorUnarmedEffect',
    'GetActorValueModifier',
    'GetActorVelocity',
    'GetActorVoiceType',
    'GetAddictionChance',
    'GetAddictionEffect',
    'GetAllItemRefs',
    'GetAllItems',
    'GetAlwaysRun',
    'GetAmmoEffectTraitNumeric',
    'GetAmmoProjectile',
    'GetAmmoTraitNumeric',
    'GetAngularVelocity',
    'GetAnimObjectIdle',
    'GetAnimSequenceFrequency',
    'GetArmorAudioTemplate',
    'GetArmorClass',
    'GetArmorRCT',
    'GetAshPileSource',
    'GetAutoMove',
    'GetBarterGoldAlt',
    'GetBarterItems',
    'GetBarterPriceMult',
    'GetBaseActorValueAlt',
    'GetBaseEffectFlag',
    'GetBaseEffectScript',
    'GetBaseFactionRank',
    'GetBaseKarma',
    'GetBipedModelList',
    'GetBodyPartData',
    'GetBodyPartDataHasPart',
    'GetBodyPartDataRagdoll',
    'GetBodyPartDataSkeleton',
    'GetBodyPartFlag',
    'GetBodyPartName',
    'GetBodyPartReplacementModel',
    'GetBodyPartTraitForm',
    'GetBodyPartTraitNumeric',
    'GetBufferedCells',
    'GetCalculatedWeaponDamage',
    'GetCasinoBJ17Stand',
    'GetCasinoBJPayout',
    'GetCasinoMaxWinnings',
    'GetCasinoNumDecks',
    'GetCasinoReelStops',
    'GetCasinoShufflePercent',
    'GetCellBuffered',
    'GetCellClimate',
    'GetCellFlag',
    'GetCellImageSpace',
    'GetCellLightingTemplate',
    'GetCellNoiseTexture',
    'GetChallengeFlags',
    'GetChallengeForm1',
    'GetChallengeForm2',
    'GetClassFlag',
    'GetClassTraitNumeric',
    'GetClimateNightSkyModel',
    'GetClimateNthWeatherChance',
    'GetClimateNthWeatherGlobal',
    'GetClimateNthWeatherType',
    'GetClimateNumWeatherTypes',
    'GetClimateSunGlareTexture',
    'GetClimateSunTexture',
    'GetClimateTraitNumeric',
    'GetCombatAllies',
    'GetCombatDisabled',
    'GetCombatStyle',
    'GetCombatStyleFlag',
    'GetCombatStyleTraitNumeric',
    'GetCombatTargets',
    'GetContactRefs',
    'GetContainerRespawns',
    'GetCreatureDamage',
    'GetCreatureModels',
    'GetCreatureType',
    'GetCreatureWeaponList',
    'GetCurrentAmmo',
    'GetCurrentAmmoRounds',
    'GetCurrentClimate',
    'GetCurrentStablePackage',
    'GetCurrentWeather',
    'GetCursorPos',
    'GetDeathItem',
    'GetDelayElapsed',
    'GetDestructionDataHealth',
    'GetDestructionDataNumStages',
    'GetDestructionDataTargetable',
    'GetDetectedActors',
    'GetDetectingActors',
    'GetDetectionValue',
    'GetDetonationTimer',
    'GetDroppedRefs',
    'GetEffectFlag',
    'GetEnableChildren',
    'GetEquippedData',
    'GetEquippedItemRef',
    'GetExplosionFlag',
    'GetExplosionTraitForm',
    'GetExplosionTraitNumeric',
    'GetExteriorCell',
    'GetFactionReputationType',
    'GetFallTimeElapsed',
    'GetFallTimeRemaining',
    'GetFollowers',
    'GetFontFile',
    'GetFormDescription',
    'GetGameDaysPassed',
    'GetGameDifficulty',
    'GetGlobalRef',
    'GetGlobalVariable',
    'GetGrassModel',
    'GetGrassTraitNumeric',
    'GetHasContact',
    'GetHasContactBase',
    'GetHasContactType',
    'GetHasPhantom',
    'GetHitAttacker',
    'GetHitHealthDamage',
    'GetHitLimbDamage',
    'GetHitProjectile',
    'GetHitWeapon',
    'GetIdleAnimPath',
    'GetIdleLoopTimes',
    'GetImageSpaceModTrait',
    'GetImageSpaceTrait',
    'GetImpactDataModel',
    'GetImpactDataTrait',
    'GetInteractionDisabled',
    'GetInteractionDisabledType',
    'GetIsItem',
    'GetIsPoison',
    'GetIsPoisoned',
    'GetIsRagdolled',
    'GetItemRefCurrentHealth',
    'GetKiller',
    'GetKillXP',
    'GetLandTextureNthGrass',
    'GetLandTextureNumGrasses',
    'GetLandTextureTextureSet',
    'GetLandTextureTraitNumeric',
    'GetLeveledActorBase',
    'GetLightFlag',
    'GetLightTraitNumeric',
    'GetLinkedChildren',
    'GetLoadOrderChanged',
    'GetLocalGravity',
    'GetMaterialPropertyValue',
    'GetMaxOf',
    'GetMenuItemFilter',
    'GetMenuTargetRef',
    'GetMerchantContainer',
    'GetMessageDisabled',
    'GetMessageFlags',
    'GetMinOf',
    'GetMoonTexture',
    'GetNifBlockFlag',
    'GetNifBlockParentNodes',
    'GetNifBlockRotation',
    'GetNifBlockScale',
    'GetNifBlockTranslation',
    'GetNoUnequip',
    'GetNthActorEffect',
    'GetNthAmmoEffect',
    'GetNthDestructionStageDebris',
    'GetNthDestructionStageExplosion',
    'GetNthDestructionStageReplacement',
    'GetNthDestructionStageTrait',
    'GetNthEffectBase',
    'GetNthEffectTraitNumeric',
    'GetNumActorEffects',
    'GetNumAmmoEffects',
    'GetNumEffects',
    'GetNVSEVersionFull',
    'GetObjectDimensions',
    'GetObjectiveHasTarget',
    'GetObjectiveTargets',
    'GetObjectiveText',
    'GetObjectUnderFeet',
    'GetObjectVelocity',
    'GetOptionalPatch',
    'GetPackageFlag',
    'GetPCDetectionState',
    'GetPCFastTravelled',
    'GetPCLastExteriorDoor',
    'GetPCMovedCell',
    'GetPCUsingIronSights',
    'GetPCUsingScope',
    'GetPerkFlag',
    'GetPerkModifier',
    'GetPipboyRadio',
    'GetPlayedIdle',
    'GetPlayerPerks',
    'GetPrimitiveBound',
    'GetProjectileExplosion',
    'GetProjectileFlag',
    'GetProjectileRefDamage',
    'GetProjectileRefDistanceTraveled',
    'GetProjectileRefLifeTime',
    'GetProjectileRefSource',
    'GetProjectileRefSpeedMult',
    'GetProjectileRefWeapon',
    'GetProjectileTraitNumeric',
    'GetRadiationLevelAlt',
    'GetRecipeMenuCategory',
    'GetRecipeMenuSelection',
    'GetRefType',
    'GetReticlePos',
    'GetReticleRange',
    'GetRigidBodyMass',
    'GetScriptDisabled',
    'GetScriptEventDisabled',
    'GetSelectedItemRef',
    'GetServiceFlag',
    'GetSkeletonModel',
    'GetSoundFlag',
    'GetSoundPlayers',
    'GetSoundSourceFile',
    'GetSoundTraitNumeric',
    'GetTargetUnreachable',
    'GetTeammates',
    'GetTeleportDoor',
    'GetTempEffects',
    'GetTerrainHeight',
    'GetTextureSetFlag',
    'GetTextureSetTexture',
    'GetTextureSetTraitNumeric',
    'GetUIString',
    'GetValueAlt',
    'GetVATSTargets',
    'GetWaterImmersionPerc',
    'GetWaterNoiseTexture',
    'GetWaterSound',
    'GetWeaponDetectionSoundLevel',
    'GetWeaponModReloadAnim',
    'GetWeaponRefModFlags',
    'GetWeaponShellCasingModel',
    'GetWeaponSound',
    'GetWeatherImageSpaceMod',
    'GetWeatherPrecipitationModel',
    'GetWeatherRGBColor',
    'GetWeatherTexture',
    'GetWeatherTraitNumeric',
    'GetWindDirection',
    'GetWorldspaceClimate',
    'GetWorldspaceFlag',
    'GetWorldspaceImagespace',
    'GetWorldspaceNoiseTexture',
    'GetWorldspaceWaterType',
    'HasEffectShader',
    'HasPrimitive',
    'HasScriptBlock',
    'HasVariableAdded',
    'HoldControl',
    'InjectUIComponent',
    'InjectUIXML',
    'IsAnimPlayingEx',
    'IsArmorAddon',
    'IsAttacking',
    'IsComponentLoaded',
    'IsEquippedWeaponScoped',
    'IsEquippedWeaponSilenced',
    'IsFleeing',
    'IsIdlePlayingEx',
    'IsInAir',
    'IsInCharGen',
    'IsInCombatWith',
    'IsInWater',
    'IsMusicPlaying',
    'IsRaceInList',
    'IsScriptWaiting',
    'IsSoundPlaying',
    'IsSpellTargetAlt',
    'KillActorAlt',
    'LandTextureAddGrass',
    'LandTextureRemoveGrass',
    'LNGetAggroRadius',
    'LNSetActorTemplate',
    'LNSetAggroRadius',
    'MarkActivatorAshPile',
    'MessageBoxExAlt',
    'MessageExAlt',
    'ModBaseActorValue',
    'ModLogPrint',
    'MoveAwayFromPlayer',
    'MoveToCell',
    'MoveToContainer',
    'MoveToEditorPosition',
    'MoveToNode',
    'MoveToReticle',
    'PlaceAtCell',
    'PlayIdleEx',
    'PushObject',
    'ReadArrayFromFile',
    'ReadStringFromFile',
    'RefHasMapMarker',
    'RefMapArrayDestroy',
    'RefMapArrayErase',
    'RefMapArrayGetAll',
    'RefMapArrayGetFirst',
    'RefMapArrayGetFloat',
    'RefMapArrayGetKeys',
    'RefMapArrayGetNext',
    'RefMapArrayGetRef',
    'RefMapArrayGetSize',
    'RefMapArrayGetString',
    'RefMapArrayGetType',
    'RefMapArraySetFloat',
    'RefMapArraySetRef',
    'RefMapArraySetString',
    'RefMapArrayValidate',
    'RefreshCurrentClimate',
    'RefreshItemsList',
    'RefToString',
    'ReleaseControl',
    'ReloadEquippedModels',
    'RemoveAllAddedVariables',
    'RemoveAmmoEffect',
    'RemoveBaseEffectListEffect',
    'RemoveDestructionStage',
    'RemoveItemTarget',
    'RemoveMeIRAlt',
    'RemoveNthEffect',
    'RemoveNthTempEffect',
    'RemoveObjectiveTarget',
    'RemoveRefMapMarker',
    'RemoveScriptVariable',
    'ResetFallTime',
    'RunBatchScript',
    'RunScriptSnippet',
    'ScriptWait',
    'SetActivatorPrompt',
    'SetActivatorRadioStation',
    'SetActivatorSoundActivate',
    'SetActivatorSoundLooping',
    'SetActivatorWaterType',
    'SetActorDiveBreath',
    'SetActorFullNameAlt',
    'SetActorLevelingData',
    'SetActorTemplateFlag',
    'SetActorUnarmedEffect',
    'SetActorVelocity',
    'SetActorVoiceType',
    'SetAddictionChance',
    'SetAddictionEffect',
    'SetAmmoEffectTraitNumeric',
    'SetAmmoProjectile',
    'SetAmmoTraitNumeric',
    'SetAngleEx',
    'SetAngularVelocity',
    'SetAnimObjectIdle',
    'SetAnimSequenceFrequency',
    'SetArmorAudioTemplate',
    'SetArmorRCT',
    'SetBarterPriceMult',
    'SetBaseEffectFlag',
    'SetBaseEffectScript',
    'SetBaseFactionRank',
    'SetBaseKarma',
    'SetBipedModelList',
    'SetBipedModelPathAlt',
    'SetBodyPartData',
    'SetBodyPartDataRagdoll',
    'SetBodyPartDataSkeleton',
    'SetBodyPartFlag',
    'SetBodyPartName',
    'SetBodyPartReplacementModel',
    'SetBodyPartTraitForm',
    'SetBodyPartTraitNumeric',
    'SetCasinoBJ17Stand',
    'SetCasinoBJPayout',
    'SetCasinoMaxWinnings',
    'SetCasinoNumDecks',
    'SetCasinoReelStops',
    'SetCasinoShufflePercent',
    'SetCellClimate',
    'SetCellFlag',
    'SetCellLightingTemplate',
    'SetCellNoiseTexture',
    'SetCellWaterForm',
    'SetChallengeFlags',
    'SetChallengeForm1',
    'SetChallengeForm2',
    'SetClassFlag',
    'SetClassTraitNumeric',
    'SetClimateNightSkyModel',
    'SetClimateSunGlareTexture',
    'SetClimateSunTexture',
    'SetClimateTraitNumeric',
    'SetCombatDisabled',
    'SetCombatStyleFlag',
    'SetCombatStyleTraitNumeric',
    'SetContainerRespawns',
    'SetCreatureDamage',
    'SetCRESkeletonModel',
    'SetCurrentAmmoRounds',
    'SetCurrentClimate',
    'SetCursorPos',
    'SetDeathItem',
    'SetDelayElapsed',
    'SetDestructionDataHealth',
    'SetDestructionDataTargetable',
    'SetDetonationTimer',
    'SetEffectFlag',
    'SetEmbeddedWeaponAV',
    'SetEmbeddedWeaponNode',
    'SetEquippedData',
    'SetExplosionFlag',
    'SetExplosionTraitForm',
    'SetExplosionTraitNumeric',
    'SetFactionReputationType',
    'SetFontFile',
    'SetFormDescription',
    'SetGameDifficulty',
    'SetGameMainLoopCallback',
    'SetGlobalRef',
    'SetGlobalVariable',
    'SetGrassModel',
    'SetGrassTraitNumeric',
    'SetHotkeyItemRef',
    'SetIdleAnimPath',
    'SetIdleLoopTimes',
    'SetImageSpaceModTrait',
    'SetImageSpaceTrait',
    'SetImpactDataModel',
    'SetImpactDataTraitForm',
    'SetImpactDataTraitNumeric',
    'SetInteractionDisabled',
    'SetInteractionDisabledType',
    'SetItemRefCurrentHealth',
    'SetLandTextureTextureSet',
    'SetLandTextureTraitNumeric',
    'SetLightFlag',
    'SetLightTraitNumeric',
    'SetLinkedReference',
    'SetLocalGravityVector',
    'SetMaterialPropertyValue',
    'SetMessageDisabled',
    'SetMessageDisplayTime',
    'SetMessageFlags',
    'SetMoonTexture',
    'SetMusicState',
    'SetNifBlockFlag',
    'SetNifBlockRotation',
    'SetNifBlockScale',
    'SetNifBlockTranslation',
    'SetNoUnequip',
    'SetNPCSkeletonModel',
    'SetNthDestructionStageDebris',
    'SetNthDestructionStageExplosion',
    'SetNthDestructionStageReplacement',
    'SetNthDestructionStageTrait',
    'SetNthEffectBase',
    'SetNthEffectTraitNumeric',
    'SetObjectEffect',
    'SetObjectiveNthTarget',
    'SetObjectiveText',
    'SetOnAnimActionEventHandler',
    'SetOnControlDownEventHandler',
    'SetOnControlUpEventHandler',
    'SetOnCrippledLimbEventHandler',
    'SetOnCriticalHitEventHandler',
    'SetOnDialogTopicEventHandler',
    'SetOnFastTravelEventHandler',
    'SetOnFireWeaponEventHandler',
    'SetOnHealthDamageEventHandler',
    'SetOnKeyDownEventHandler',
    'SetOnKeyUpEventHandler',
    'SetOnMenuClickEventHandler',
    'SetOnMenuCloseEventHandler',
    'SetOnMenuOpenEventHandler',
    'SetOnMouseoverChangeEventHandler',
    'SetOnPCTargetChangeEventHandler',
    'SetOnPlayGroupEventHandler',
    'SetOnQuestStageEventHandler',
    'SetOnTriggerDownEventHandler',
    'SetOnTriggerUpEventHandler',
    'SetOptionalPatch',
    'SetPackageFlag',
    'SetPerkFlag',
    'SetPersistent',
    'SetPosEx',
    'SetPrimitiveBound',
    'SetProjectileExplosion',
    'SetProjectileFlag',
    'SetProjectileRefDamage',
    'SetProjectileRefSource',
    'SetProjectileRefSpeedMult',
    'SetProjectileRefWeapon',
    'SetProjectileTraitNumeric',
    'SetRace',
    'SetRefName',
    'SetScaleEx',
    'SetScriptDisabled',
    'SetScriptEventDisabled',
    'SetServiceFlag',
    'SetSoundFlag',
    'SetSoundSourceFile',
    'SetSoundTraitNumeric',
    'SetSpeedMult',
    'SetStageAlt',
    'SetTerminalUIModel',
    'SetTextureSetFlag',
    'SetTextureSetTexture',
    'SetTextureSetTraitNumeric',
    'SetValueAlt',
    'SetVATSTargetable',
    'SetWaterFormEffect',
    'SetWaterNoiseTexture',
    'SetWaterSound',
    'SetWeaponDetectionSoundLevel',
    'SetWeaponItemMod',
    'SetWeaponItemModEffect',
    'SetWeaponItemModValue',
    'SetWeaponModReloadAnim',
    'SetWeaponOut',
    'SetWeaponRefModFlags',
    'SetWeaponShellCasingModel',
    'SetWeaponSound',
    'SetWeatherImageSpaceMod',
    'SetWeatherPrecipitationModel',
    'SetWeatherRGBColor',
    'SetWeatherTexture',
    'SetWeatherTraitNumeric',
    'SetWeatherTransitionTimeOverride',
    'SetWindDirection',
    'SetWorldspaceClimate',
    'SetWorldspaceFlag',
    'SetWorldspaceImagespace',
    'SetWorldspaceNoiseTexture',
    'SetWorldspaceWaterType',
    'ShowQuantityMenu',
    'ShowTextInputMenu',
    'StopIdle',
    'StopScriptWaiting',
    'StopSound',
    'StringToRef',
    'Sv_RegexMatch',
    'Sv_RegexReplace',
    'Sv_RegexSearch',
    'SwapTextureEx',
    'TapButton',
    'TapTrigger',
    'ToggleCreatureModel',
    'ToggleFirstPerson',
    'ToggleHardcoreTracking',
    'ToggleObjectCollision',
    'TriggerLightningFX',
    'Turn',
    'UnequipItemAlt',
    'UnloadUIComponent',
    'ValidateModIndex',
    'WriteArrayToFile',
    'WriteStringToFile'
  ].join('|'),

  /**
   * Combines an entire set of keywords and/or function names and returns
   * them as a single string prefixed with (?i)\b, optionally adding [_]?,
   * then ( followed by the combined set of lists and ending with )\b.
   *
   * This creates a large list where each of the individual terms are included
   * in a given search. The (?i) is the way to set case insensitivity in a
   * regular expression string.
   *
   * Expected usage:
   *   var pack = atom.packages.activePackages['language-geck'].mainModule;
   *   var geck = pack.syntax;
   *   var allFns = geck.getSet(
   *         geck.geckFns,
   *         geck.vegasFns,
   *         geck.foseFns,
   *         geck.nvseFns
   *       );
   *   var blockwords = geck.getSet(geck.blocktypes, true);
   *
   * @param ...sets this is n-number of arrays of keywords, ideally from the
   * lists defined in this object.
   * @param allowOverloads if true, [_]? is prepended to the opening
   * parenthesis to allow matching of block types or other functions that
   * have different meaning with NVSE
   * @return a string denoting of the combined values.
   */
  getSet: function(...sets /*, allowOverloads=false */) {
    var allowOverloads = false;

    var lastValue = sets[sets.length-1];
    if (lastValue === true || lastValue === false) {
      allowOverloads = sets.splice(sets.length - 1, 1);
    }

    var result = ['(?i)\\b', allowOverloads ? '[_]?' : '', '('];
    sets.forEach((set, index, array) => {
      if (index > 0) { result.push('|'); }
      result = result.concat(set);
    });
    result.push(')\\b');

    return result.join('');
  },

  /**
   * Returns a set of terms as a regular expression. The way it does this is
   * to take results from getSet(...) and create a new RegExp() object to
   * return, using any supplied options.
   *
   * @param regExOpts a string with regular expression flags
   * @param ...sets the same parameters that would apply to this.getSet()
   * @return a valid RegExp object
   */
  getRegExp: function(...getSetParams /*, regExOpts = "i" */) {
    require('isa-lib')(window);

    var regExOpts = "i";

    var lastValue = getSetParams[getSetParams.length - 1];
    if (isString(lastValue) && /^[gimy]*$/.exec(lastValue)) {
      regExOpts = getSetParams.splice(getSetParams.length - 1, 1);
    }

    var regExString = this.getSet(...getSetParams).replace(/\(\?\i\)/g, '');
    var result = new RegExp(regExString, regExOpts);

    return result;
  }
};

Syntax.fo3Fns = []
  .concat(Syntax.geckFns.split('|'))
  .concat(Syntax.foseFns.split('|'))
  .join('|');

Syntax.fonvFns = []
  .concat(Syntax.geckFns.split('|'))
  .concat(Syntax.vegasFns.split('|'))
  .concat(Syntax.foseFns.split('|'))
  .concat(Syntax.nvseFns.split('|'))
  .concat(Syntax.lutanaFns.split('|'))
  .concat(Syntax.jipFns.split('|'))
  .join('|');

Syntax.allFns = []
  .concat(Syntax.fonvFns.split('|'))
  .concat(Syntax.nxFns.split('|'))
  .join('|');

module.exports = Syntax;
